# tabular-automl
A light wrapper around popular Python machine learning frameworks for tabular data

[![Tests](https://github.com/harisonmg/tabular-automl/actions/workflows/ci.yml/badge.svg)](https://github.com/harisonmg/tabular-automl/actions/workflows/ci.yml)
[![Coverage Status](https://coveralls.io/repos/github/harisonmg/tabular-automl/badge.svg?branch=main)](https://coveralls.io/github/harisonmg/tabular-automl?branch=main)
